=======
History
=======

0.0.1 (2019-01-24)
------------------

* First release on PyPI.

0.0.4 (2019-04-26)
------------------

* Updated syntax for binblockread to mimic that of PyVISA. Created documentation.
